@@ -22,7 +22,7 @@
 #' animate(flea[, 1:6], tour_path=grand_tour(),
 #'   display=display_xy(half_range = 0.5))
 #' animate_xy(flea[, 1:6], tour_path=little_tour())
-#' animate_xy(flea[, 1:3], tour_path=guided_tour(holes), sphere = TRUE)
+#' animate_xy(flea[, 1:3], tour_path=guided_tour(holes()), sphere = TRUE)
 #' animate_xy(flea[, 1:6], center = FALSE)
 #'
 #' # The default axes are centered, like a biplot, but there are other options
@@ -39,8 +39,7 @@
 #' edges <- matrix(c(1:5, 2:6), ncol = 2)
 #' animate(flea[, 1:6], grand_tour(),
 #'   display_xy(axes = "bottomleft", edges = edges))
-display_xy <- function(center = TRUE, axes = "center", half_range = NULL,
-                       col = "black", pch  = 20, edges = NULL, ...) {
+display_xy <- function(center = TRUE, axes = "center", half_range = NULL, col = "black", pch  = 20, edges = NULL, ...) {
 
   labels <- NULL
   init <- function(data) {
@@ -71,7 +70,8 @@ display_xy <- function(center = TRUE, axes = "center", half_range = NULL,
     points(x, col = col, pch = pch)
 
     if (!is.null(edges)) {
-      lines(x[edges, 1], x[edges, 2])
+      segments(x[edges[,1], 1], x[edges[,1], 2],
+               x[edges[,2], 1], x[edges[,2], 2])
     }
   }
 
@@ -88,7 +88,7 @@ display_xy <- function(center = TRUE, axes = "center", half_range = NULL,
 #' @inheritParams animate
 #' @export
 animate_xy <- function(data, tour_path = grand_tour(), ...) {
-  animate(data, tour_path, display_xy(...))
+  animate(data, tour_path, display_xy(...), ...)
 }
 
 #' Draw tour axes with base graphics
