@@ -34,17 +34,17 @@
 #'
 #' testdata <- matrix(rnorm(100*3), ncol=3)
 #' testdata[1:50, 1] <- testdata[1:50, 1] + 10
-#' testdata <- sphere(testdata)
-#' t2 <- save_history(testdata, guided_tour(holes, max.tries = 100),
+#' testdata <- sphere_data(testdata)
+#' t2 <- save_history(testdata, guided_tour(holes(), max.tries = 100),
 #'   max = 5, rescale=FALSE)
 #' animate_xy(testdata, planned_tour(t2))
 #'
 #' # Or you can use saved histories to visualise the path that the tour took.
-#' plot(path_index(interpolate(t2), holes))
+#' plot(path_index(interpolate(t2), holes()))
 #' plot(path_curves(interpolate(t2)))
 save_history <- function(data, tour_path = grand_tour(), max_bases = 100, start = NULL, rescale = TRUE, sphere = FALSE, step_size = Inf){
   if (rescale) data <- rescale(data)
-  if (sphere) data  <- sphere(data)
+  if (sphere) data  <- sphere_data(data)
 
   tour <- new_tour(data, tour_path, start)
   start <- tour(0)$proj
@@ -58,9 +58,9 @@ save_history <- function(data, tour_path = grand_tour(), max_bases = 100, start
     # An infinite step size forces the tour path to generate a new basis
     # every time, so no interpolation occurs.
     step <- tour(step_size)
-    if (is.null(step)) break
 
     projs[, , i] <- step$target
+    if (step$step < 0) break #already appended final projection, break directly
   }
 
   # Remove empty matrices for tours that terminated early
