@@ -40,9 +40,15 @@ new_tour <- function(data, tour_path, start = NULL) {
     cur_dist <<- cur_dist + step_size
 
     # We're at (or past) the target, so generate a new one and reset counters
+    if (step_size > 0 & is.finite(step_size) & cur_dist >= target_dist) {
+      proj <<- geodesic$interpolate(1.) #make sure next starting plane is previous target
+    }
+
     if (cur_dist >= target_dist) {
       geodesic <<- tour_path(proj, data)
-      if (is.null(geodesic)) return(NULL)
+      if (is.null(geodesic)) {
+        return(list(proj = proj, target = target, step = -1)) #use negative step size to signal that we have reached the final target
+      }
 
       target_dist <<- geodesic$dist
       target <<- geodesic$Fz
